==> 0.0.44.tar.gz: lib/nui_persistent_bottom_sheet.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'nui_header_tab_widget.dart';

typedef NUIDraggableSheetOnScrollListener = void Function(DraggableScrollableNotification notification, bool expanded, bool collapsed);
typedef NUIDraggableSheetInnerScrollListener = void Function(double offset);

class NUIDraggableSheetBehaviour extends ScrollBehavior {
  @override
  Widget buildViewportChrome(BuildContext context, Widget child, AxisDirection axisDirection) {
    return child;
  }
}

class NUIDraggableSheet extends StatefulWidget {
  NUIDraggableSheet({@required this.child, this.collapseAtFirst: true, this.collapseRatio: 0.2, this.decoration, this.expandRatio: 0.8, this.scrollListener, this.expandAcceptMargin: 0.0, this.header, this.innerScrollListener});
  final double collapseRatio;
  final double expandRatio;
  final bool collapseAtFirst;
  final double expandAcceptMargin;
  final Widget child;
  final NUIPersistentHeader header;
  final BoxDecoration decoration;
  final NUIDraggableSheetOnScrollListener scrollListener;
  final NUIDraggableSheetInnerScrollListener innerScrollListener;
  @override
  State<StatefulWidget> createState() => _NUIDraggableSheetState();
}

class _NUIDraggableSheetState extends State<NUIDraggableSheet> {
  bool _isExpanded = false;
  double _initialExtent;
  BuildContext _draggableSheetContext;
  Function _innerScrollListener;

  @override
  void initState(){
    super.initState();
    this._initialExtent = widget.collapseAtFirst == true ? widget.collapseRatio : widget.expandRatio;
    _innerScrollListener = (){};
  }

  @override
  Widget build(BuildContext context) {
    return _buildBody();
  }

  Widget _buildBody() {
    return NotificationListener<DraggableScrollableNotification>(
      onNotification: (DraggableScrollableNotification notification){
        bool expanded = notification.extent >= widget.expandRatio - (widget.expandAcceptMargin ?? 0.0);
        bool collapsed = notification.extent <= widget.collapseRatio;
        if(widget.scrollListener != null) widget.scrollListener(notification, expanded, collapsed);
        return false;
      },
      child: DraggableScrollableActuator(
        child: DraggableScrollableSheet(
          key: Key(_initialExtent.toString()),
          minChildSize: widget.collapseRatio,
          maxChildSize: widget.expandRatio,
          initialChildSize: _initialExtent,
          builder: _draggableScrollableSheetBuilder,
        ),
      ),
    );
  }

  void _toggleDraggableScrollableSheet() {
    if (_draggableSheetContext != null) {
      setState(() {
        _initialExtent = _isExpanded ? widget.collapseRatio : widget.expandRatio;
        _isExpanded = !_isExpanded;
      });
      DraggableScrollableActuator.reset(_draggableSheetContext);
    }
  }

  Widget _draggableScrollableSheetBuilder(BuildContext context, ScrollController scrollController) {
    scrollController.removeListener(_innerScrollListener);
    _innerScrollListener = (){
      if(widget.innerScrollListener != null) widget.innerScrollListener(scrollController.offset);
    };
    scrollController.addListener(_innerScrollListener);

    _draggableSheetContext = context;
    Widget contentBody;
    if(widget.header == null){
      contentBody = SingleChildScrollView(
        controller: scrollController,
        child: Column(
            children: [
              widget.child
            ]
        ),
      );
    }
    else{
      contentBody = CustomScrollView(
        controller: scrollController,
        slivers: [
          SliverPersistentHeader(
              pinned: true,
              delegate: widget.header
          ),
          SliverList(
            delegate: SliverChildListDelegate(
              [
                widget.child
              ],
            ),
          ),
        ],
      );
    }

    return ScrollConfiguration(
      behavior: NUIDraggableSheetBehaviour(),
      child: Container(
          decoration: widget.decoration,
          child: contentBody
      ),
    );
  }
}

==> 0.0.48.tar.gz: lib/nui_persistent_bottom_sheet.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'nui_header_tab_widget.dart';

typedef NUIDraggableSheetOnScrollListener = void Function(DraggableScrollableNotification notification, bool expanded, bool collapsed);
typedef NUIDraggableSheetInnerScrollListener = void Function(double offset);

class NUIDraggableSheetBehaviour extends ScrollBehavior {
  @override
  Widget buildViewportChrome(BuildContext context, Widget child, AxisDirection axisDirection) {
    return child;
  }
}

class NUIDraggableSheet extends StatefulWidget {
  NUIDraggableSheet({@required this.child, this.collapseAtFirst: true, this.collapseRatio: 0.2, this.decoration, this.expandRatio: 0.8, this.scrollListener, this.expandAcceptMargin: 0.0, this.header, this.innerScrollListener});
  final double collapseRatio;
  final double expandRatio;
  final bool collapseAtFirst;
  final double expandAcceptMargin;
  final Widget child;
  final NUIPersistentHeader header;
  final BoxDecoration decoration;
  final NUIDraggableSheetOnScrollListener scrollListener;
  final NUIDraggableSheetInnerScrollListener innerScrollListener;
  @override
  State<StatefulWidget> createState() => _NUIDraggableSheetState();
}

class _NUIDraggableSheetState extends State<NUIDraggableSheet> {
  bool _isExpanded = false;
  double _initialExtent;
  BuildContext _draggableSheetContext;
  Function _innerScrollListener;
  double _currentExtent;

  @override
  void initState(){
    super.initState();
    this._initialExtent = widget.collapseAtFirst == true ? widget.collapseRatio : widget.expandRatio;
    this._currentExtent = _initialExtent;
    _innerScrollListener = (){};
  }

  @override
  Widget build(BuildContext context) {
    return _buildBody();
  }

  Widget _buildBody() {
    return NotificationListener<DraggableScrollableNotification>(
      onNotification: (DraggableScrollableNotification notification){
        bool expanded = notification.extent >= widget.expandRatio - (widget.expandAcceptMargin ?? 0.0);
        bool collapsed = notification.extent <= widget.collapseRatio;
        _currentExtent = notification.extent;
        if(widget.scrollListener != null) widget.scrollListener(notification, expanded, collapsed);
        return false;
      },
      child: DraggableScrollableActuator(
        child: DraggableScrollableSheet(
          key: Key(_initialExtent.toString()),
          minChildSize: widget.collapseRatio,
          maxChildSize: widget.expandRatio,
          initialChildSize: _currentExtent,
          builder: _draggableScrollableSheetBuilder,
        ),
      ),
    );
  }

  void _toggleDraggableScrollableSheet() {
    if (_draggableSheetContext != null) {
      setState(() {
        _initialExtent = _isExpanded ? widget.collapseRatio : widget.expandRatio;
        _isExpanded = !_isExpanded;
      });
      DraggableScrollableActuator.reset(_draggableSheetContext);
    }
  }

  Widget _draggableScrollableSheetBuilder(BuildContext context, ScrollController scrollController) {
    scrollController.removeListener(_innerScrollListener);
    _innerScrollListener = (){
      if(widget.innerScrollListener != null) widget.innerScrollListener(scrollController.offset);
    };
    scrollController.addListener(_innerScrollListener);

    _draggableSheetContext = context;
    Widget contentBody;
    if(widget.header == null){
      contentBody = SingleChildScrollView(
        controller: scrollController,
        child: Column(
            children: [
              widget.child
            ]
        ),
      );
    }
    else{
      contentBody = CustomScrollView(
        controller: scrollController,
        slivers: [
          SliverPersistentHeader(
              pinned: true,
              delegate: widget.header
          ),
          SliverList(
            delegate: SliverChildListDelegate(
              [
                widget.child
              ],
            ),
          ),
        ],
      );
    }

    return ScrollConfiguration(
      behavior: NUIDraggableSheetBehaviour(),
      child: Container(
          decoration: widget.decoration,
          child: contentBody
      ),
    );
  }
}
